@@ -1,12 +1,15 @@
+from .timelike import *
+from .wavelike import *
+from .models import *
+from .diagnostics import *
+
+
 from .colors import *
 from .imshow import *
 from .plot_lightcurves import *
 from .animate import *
-from .diagnostics import *
 from .interactive import *
 from .plot_spectra import *
 from .plot import *
 from .utilities import *
 from .pcolormesh import *
-from .plot_noise_comparison import *
-from .models import *
