@@ -6,7 +6,7 @@ __all__ = ["plot_average_spectrum"]
 
 def plot_average_spectrum(self, **kw):
     """
-    Plot the weighted average average_average_spectrum as a function of wavelength.
+    Plot the weighted average spectrum as a function of wavelength.
 
     Parameters
     ----------
@@ -16,14 +16,9 @@ def plot_average_spectrum(self, **kw):
         docstrings for options about plot appearance and layout.
     """
     y = self.get_average_spectrum()
-    y_unit = u.Quantity(y).unit
-    if y_unit == u.Unit(""):
-        unit_string = "unitless"
-    else:
-        unit_string = y_unit.to_string("latex_inline")
     self._scatter_timelike_or_wavelike(
         x=self.wavelength,
         y=y,
-        ylabel=f"Flux ({unit_string})",
+        ylabel=f"Flux ({_get_unit_string(y)})",
         **kw,
     )
